==> wsclient-8.0.4-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wsresources/WsResourcesPingResponseWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wsresources;



/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2019 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: WsResourcesPingResponseWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingResponse
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wsresources
 * TimeStamp: 2021-03-26T16:29:03.972Z
 */
public class WsResourcesPingResponseWrapper
{

	public WsResourcesPingResponseWrapper() {}

	public org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingResponse getRaw()
	{
		org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingResponse raw = new org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingResponse();
		return raw;
	}


}

==> wsclient-9.4.24-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wsresources/WsResourcesPingResponseWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wsresources;

/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2021 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: WsResourcesPingResponseWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingResponse
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wsresources
 */
public class WsResourcesPingResponseWrapper
{

    public WsResourcesPingResponseWrapper() {}

    public org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingResponse getRaw()
    {
        org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingResponse raw = new org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingResponse();
        return raw;
    }


}
